@@ -33,7 +33,11 @@ public:
     Q_REQUIRED_RESULT QMimeData *mimeData() const;
 
 protected:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
+#else
+    QMimeData *mimeData(const QList<QListWidgetItem *> &items) const override;
+#endif
     void startDrag(Qt::DropActions supportedActions) override;
     void keyPressEvent(QKeyEvent *event) override;
 };
@@ -74,4 +78,3 @@ private:
     QUrl mTempFile;
 };
 }
-
